@@ -20,6 +20,156 @@
 #' @include f_core_constants.R
 NULL
 
+PlotSubTitleItem <- setRefClass("PlotSubTitleItem",
+	fields = list(
+		title = "character",
+		subscript = "character",
+		value = "numeric"
+	),
+	methods = list(
+		toQuote = function() {
+			if (!is.null(subscript) && length(subscript) == 1 && !is.na(subscript)) {
+				return(bquote(' '*.(title)[.(subscript)] == .(value)))
+			}
+			
+			return(bquote(' '*.(title) == .(value)))
+		}
+	)
+)
+
+PlotSubTitleItems <- setRefClass("PlotSubTitleItems",
+	fields = list(
+		title = "character",
+		subTitle = "character",
+		items = "list"
+	),
+	methods = list(
+		initialize = function(...) {
+			callSuper(...)
+			items <<- list()
+		},
+		
+		addItem = function(item) {
+			items <<- c(items, item)
+		},
+		
+		add = function(title, value, subscript = NA_character_) {
+			titleTemp <- title
+			if (length(items) == 0) {
+				titleTemp <- .firstCharacterToUpperCase(titleTemp)
+			}
+			
+			titleTemp <- paste0(' ', titleTemp)
+			if (length(subscript) > 0 && !is.na(subscript)) {
+				subscript <- paste0(as.character(subscript), ' ')
+			} else {
+				titleTemp <- paste0(titleTemp, ' ')
+			}
+			addItem(PlotSubTitleItem(title = titleTemp, subscript = subscript, value = value))
+		},
+		
+		toQuote = function() {
+			quotedItems <- .getQuotedItems()
+			if (is.null(quotedItems)) {
+				if (length(subTitle) > 0) {
+					return(bquote(atop(bold(.(title)), 
+						atop(.(subTitle)))))
+				}
+				
+				return(title)
+			}
+			
+			if (length(subTitle) > 0) {
+				return(bquote(atop(bold(.(title)), 
+							atop(.(subTitle)*','~.(quotedItems)))))
+			}
+			
+			return(bquote(atop(bold(.(title)), 
+				atop(.(quotedItems)))))
+		},
+		
+		.getQuotedItems = function() {
+			item1 <- NULL
+			item2 <- NULL
+			item3 <- NULL
+			item4 <- NULL
+			if (length(items) > 0) {
+				item1 <- items[[1]]
+			}
+			if (length(items) > 1) {
+				item2 <- items[[2]]
+			}
+			if (length(items) > 2) {
+				item3 <- items[[3]]
+			}
+			if (length(items) > 3) {
+				item4 <- items[[4]]
+			}
+			
+			if (!is.null(item1) && !is.null(item2) && !is.null(item3) && !is.null(item4)) {
+				if (length(item1$subscript) == 1 && !is.na(item1$subscript) &&
+					length(item2$subscript) == 1 && !is.na(item2$subscript)) {
+					return(bquote(' '*.(item1$title)[.(item1$subscript)] == .(item1$value)*','~.(item2$title)[.(item2$subscript)] == .(item2$value)*','~.(item3$title) == .(item3$value)*','~.(item4$title) == .(item4$value)*''))
+				}
+				
+				if (length(item1$subscript) == 1 && !is.na(item1$subscript)) {
+					return(bquote(' '*.(item1$title)[.(item1$subscript)] == .(item1$value)*','~.(item2$title) == .(item2$value)*','~.(item3$title) == .(item3$value)*','~.(item4$title) == .(item4$value)*''))
+				}
+				
+				if (length(item2$subscript) == 1 && !is.na(item2$subscript)) {
+					return(bquote(' '*.(item1$title) == .(item1$value)*','~.(item2$title)[.(item2$subscript)] == .(item2$value)*','~.(item3$title) == .(item3$value)*','~.(item4$title) == .(item4$value)*''))
+				}
+				
+				return(bquote(' '*.(item1$title) == .(item1$value)*','~.(item2$title) == .(item2$value)*','~.(item3$title) == .(item3$value)*','~.(item4$title) == .(item4$value)*''))
+			}
+			
+			if (!is.null(item1) && !is.null(item2) && !is.null(item3)) {
+				if (length(item1$subscript) == 1 && !is.na(item1$subscript) &&
+						length(item2$subscript) == 1 && !is.na(item2$subscript)) {
+					return(bquote(' '*.(item1$title)[.(item1$subscript)] == .(item1$value)*','~.(item2$title)[.(item2$subscript)] == .(item2$value)*','~.(item3$title) == .(item3$value)*''))
+				}
+				
+				if (length(item1$subscript) == 1 && !is.na(item1$subscript)) {
+					return(bquote(' '*.(item1$title)[.(item1$subscript)] == .(item1$value)*','~.(item2$title) == .(item2$value)*','~.(item3$title) == .(item3$value)*''))
+				}
+				
+				if (length(item2$subscript) == 1 && !is.na(item2$subscript)) {
+					return(bquote(' '*.(item1$title) == .(item1$value)*','~.(item2$title)[.(item2$subscript)] == .(item2$value)*','~.(item3$title) == .(item3$value)*''))
+				}
+				
+				return(bquote(' '*.(item1$title) == .(item1$value)*','~.(item2$title) == .(item2$value)*','~.(item3$title) == .(item3$value)*''))
+			}
+			
+			if (!is.null(item1) && !is.null(item2)) {
+				if (length(item1$subscript) == 1 && !is.na(item1$subscript) &&
+						length(item2$subscript) == 1 && !is.na(item2$subscript)) {
+					return(bquote(' '*.(item1$title)[.(item1$subscript)] == .(item1$value)*','~.(item2$title)[.(item2$subscript)] == .(item2$value)*''))
+				}
+
+				if (length(item1$subscript) == 1 && !is.na(item1$subscript)) {
+					return(bquote(' '*.(item1$title)[.(item1$subscript)] == .(item1$value)*','~.(item2$title) == .(item2$value)*''))
+				}
+				
+				if (length(item2$subscript) == 1 && !is.na(item2$subscript)) {
+					return(bquote(' '*.(item1$title) == .(item1$value)*','~.(item2$title)[.(item2$subscript)] == .(item2$value)*''))
+				}
+				
+				return(bquote(' '*.(item1$title) == .(item1$value)*','~.(item2$title) == .(item2$value)*''))
+			}
+			
+			if (!is.null(item1)) {
+				if (length(item1$subscript) == 1 && !is.na(item1$subscript)) {
+					return(bquote(' '*.(item1$title)[.(item1$subscript)] == .(item1$value)*''))
+				}
+				
+				return(bquote(' '*.(item1$title) == .(item1$value)*''))
+			}
+			
+			return(NULL)
+		}
+	)
+)
+
 #' 
 #' @name FieldSet
 #' 
@@ -29,26 +179,77 @@ NULL
 #' @description 
 #' Basic class for field sets.
 #' 
-#' @name FieldSet_initialize
-#' Initializes the object.
-#' 
 #' @details
 #' The field set implements basic functions for a set of fields.
 #' 
+#' @include class_core_plot_settings.R
+#' 
 #' @keywords internal
 #' 
 #' @importFrom methods new
 #' 
 FieldSet <- setRefClass("FieldSet",
+	fields = list(
+		.parameterTypes = "list",
+		.parameterNames = "list",
+		.parameterFormatFunctions = "list",
+		.showParameterTypeEnabled = "logical",
+		.catLines = "character"
+	),
 	methods = list(
 		.getFieldNames = function() {
 			return(names(.self$getRefClass()$fields()))
 		},
+		
 		.getVisibleFieldNames = function() {
 			fieldNames <- names(.self$getRefClass()$fields())
 			fieldNames <- fieldNames[!startsWith(fieldNames, ".")]
 			return(fieldNames)
 		},
+		
+		.resetCat = function() {
+			.catLines <<- character(0)
+		},
+		
+		.cat = function(..., file = "", sep = "", fill = FALSE, labels = NULL, 
+			append = FALSE, heading = 0, consoleOutputEnabled = TRUE) {
+			
+			if (consoleOutputEnabled) {
+				cat(..., file = file, sep = sep, fill = fill, labels = labels, append = append)
+				return(invisible())
+			}
+			
+			args <- list(...)
+			line <- ""
+			if (length(args) > 0) {
+				line <- paste0(args, collapse = sep)
+				listItemEnabled <- grepl("^  ", line)
+				if (heading > 0) {
+					headingCmd <- paste0(rep("#", heading + 1), collapse = "")
+					line <- paste0(headingCmd, " ", sub(": *", "", line))
+				} else {
+					parts <- strsplit(line, " *: ")[[1]]
+					if (length(parts) == 2) {
+						line <- paste0("*", trimws(parts[1]), "*: ", parts[2])
+					}
+				}
+				if (listItemEnabled) {
+					if (grepl("^  ", line)) {
+						line <- sub("^  ", "* ", line)
+					} else {
+						line <- paste0("* ", line)
+					}
+				}
+				
+			}
+			if (length(.catLines) == 0) {
+				.catLines <<- line
+			} else {
+				.catLines <<- c(.catLines, line)
+			}
+			return(invisible())
+		},
+		
 		.getFields = function(values) {
 			flds = names(.self$getRefClass()$fields())
 			if (!missing(values)) {
@@ -72,9 +273,6 @@ FieldSet <- setRefClass("FieldSet",
 #' @description 
 #' Basic class for parameter sets.
 #' 
-#' @name ParameterSet_initialize
-#' Initializes the object.
-#' 
 #' @details
 #' The parameter set implements basic functions for a set of parameters.
 #' 
@@ -90,7 +288,8 @@ ParameterSet <- setRefClass("ParameterSet",
 		.parameterTypes = "list",
 		.parameterNames = "list",
 		.parameterFormatFunctions = "list",
-		.showParameterTypeEnabled = "logical"
+		.showParameterTypeEnabled = "logical",
+		.catLines = "character"
 	),
 	methods = list(
 		initialize = function(...,
@@ -100,14 +299,17 @@ ParameterSet <- setRefClass("ParameterSet",
 			.parameterTypes <<- list()
 			.parameterNames <<- list()
 			.parameterFormatFunctions <<- list()
+			.catLines <<- character(0)
 		},
+		
 		.initParameterTypes = function() {
 			for (parameterName in names(.parameterNames)) {
 				.parameterTypes[[parameterName]] <<- C_PARAM_TYPE_UNKNOWN
 			}
 		},
+		
 		.getParameterType = function(parameterName) {
-			if (is.null(parameterName) || is.na(parameterName) || length(parameterName) == 0) {
+			if (is.null(parameterName) || length(parameterName) == 0 || is.na(parameterName)) {
 				stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, 
 					"'parameterName' must be a valid character with length > 0")
 			}
@@ -119,11 +321,13 @@ ParameterSet <- setRefClass("ParameterSet",
 			
 			return(parameterType[1])
 		},
+		
 		.getParametersToShow = function() {
 			return(.getVisibleFieldNames())
 		},
+		
 		.setParameterType = function(parameterName, parameterType) {
-			if (is.null(parameterName) || is.na(parameterName) || length(parameterName) == 0) {
+			if (is.null(parameterName) || length(parameterName) == 0 || is.na(parameterName)) {
 				stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, 
 					"'parameterName' must be a valid character with length > 0")
 			}
@@ -140,38 +344,83 @@ ParameterSet <- setRefClass("ParameterSet",
 			
 			invisible(parameterType)
 		},
+		
 		isUserDefinedParameter = function(parameterName) {
 			return(.getParameterType(parameterName) == C_PARAM_USER_DEFINED)
 		},
+		
 		isDefaultParameter = function(parameterName) {
 			return(.getParameterType(parameterName) == C_PARAM_DEFAULT_VALUE)
 		},
+		
 		isGeneratedParameter = function(parameterName) {
 			return(.getParameterType(parameterName) == C_PARAM_GENERATED)
 		},
+		
 		isDerivedParameter = function(parameterName) {
 			return(.getParameterType(parameterName) == C_PARAM_DERIVED)
 		},
+		
 		isUndefinedParameter = function(parameterName) {
 			return(.getParameterType(parameterName) == C_PARAM_TYPE_UNKNOWN)
 		},
+		
+		.getInputParameters = function() {
+			params <- .getParametersOfOneGroup(c(C_PARAM_USER_DEFINED, C_PARAM_DEFAULT_VALUE))
+			if (inherits(.self, "TrialDesignPlanSurvival") &&
+					.self$.objectType == "sampleSize") {
+				params <- params[params != "calculateFollowUpTime"]
+			}
+			return(params)
+		},
+		
 		.getUserDefinedParameters = function() {
 			return(.getParametersOfOneGroup(C_PARAM_USER_DEFINED))
 		},
+		
 		.getDefaultParameters = function() {
 			return(.getParametersOfOneGroup(C_PARAM_DEFAULT_VALUE))
 		},
+		
 		.getGeneratedParameters = function() {
 			return(.getParametersOfOneGroup(C_PARAM_GENERATED))
 		},
+		
 		.getDerivedParameters = function() {
 			return(.getParametersOfOneGroup(C_PARAM_DERIVED))
 		},
+		
 		.getUndefinedParameters = function() {
 			return(.getParametersOfOneGroup(C_PARAM_TYPE_UNKNOWN))
 		},
+		
+		.getParameterValueIfUserDefined = function(parameterName) {
+			if (isUserDefinedParameter(parameterName) || isDefaultParameter(parameterName)) {
+				return(.self[[parameterName]])
+			}
+			
+			parameterType <- .self$getRefClass()$fields()[[parameterName]]
+			if (parameterType == "numeric") {
+				return(NA_real_)
+			}
+			
+			if (parameterType == "integer") {
+				return(NA_integer_)
+			}
+			
+			if (parameterType == "character") {
+				return(NA_character_)
+			}
+			
+			return(NA)
+		},
+		
 		.getParametersOfOneGroup = function(parameterType) {
-			parameterNames <- names(.parameterTypes[.parameterTypes == parameterType])
+			if (length(parameterType) == 1) {
+				parameterNames <- names(.parameterTypes[.parameterTypes == parameterType])
+			} else {
+				parameterNames <- names(.parameterTypes[which(.parameterTypes %in% parameterType)])
+			}
 			parametersToShow <- .getParametersToShow()
 			if (is.null(parametersToShow) || length(parametersToShow) == 0) {
 				return(parameterNames)
@@ -179,6 +428,7 @@ ParameterSet <- setRefClass("ParameterSet",
 			
 			return(parametersToShow[parametersToShow %in% parameterNames])
 		},
+		
 		.showParameterType = function(parameterName) {
 			if (!.showParameterTypeEnabled) {
 				return("  ")
@@ -186,6 +436,7 @@ ParameterSet <- setRefClass("ParameterSet",
 			
 			return(paste0("[", .getParameterType(parameterName), "]"))
 		},
+		
 		.isMatrix = function(param) {
 			if (missing(param) || is.null(param) || is.list(param)) {
 				return(FALSE)
@@ -193,6 +444,7 @@ ParameterSet <- setRefClass("ParameterSet",
 			
 			return(is.matrix(param))
 		},
+		
 		.isVector = function(param) {
 			if (missing(param) || is.null(param) || is.list(param)) {
 				return(FALSE)
@@ -200,12 +452,15 @@ ParameterSet <- setRefClass("ParameterSet",
 			
 			return(length(param) > 1)
 		},
-		.showAllParameters = function() {
+		
+		.showAllParameters = function(consoleOutputEnabled = TRUE) {
 			parametersToShow <- .getVisibleFieldNamesOrdered()
 			for (parameter in parametersToShow) {
-				.showParameter(parameter, showParameterType = TRUE)
+				.showParameter(parameter, showParameterType = TRUE, 
+					consoleOutputEnabled = consoleOutputEnabled)
 			}
 		},
+		
 		.getVisibleFieldNamesOrdered = function() {
 			visibleFieldNames <- .getVisibleFieldNames()
 			
@@ -218,15 +473,29 @@ ParameterSet <- setRefClass("ParameterSet",
 			visibleFieldNames <- c(parametersToShowSorted, visibleFieldNames)
 			return(visibleFieldNames)
 		},
-		.getOrderedParameters = function(parametersToOrder) {
-			
+		
+		.show = function(consoleOutputEnabled = FALSE) {
+			stop("Method '.show()' is not implemented in class '", class(.self), "'")
 		},
-		.showParametersOfOneGroup = function(parameters, title, orderByParameterName = TRUE) {
+		
+		.catMarkdownText = function() {
+			.show(consoleOutputEnabled = FALSE)
+			if (length(.catLines) == 0) {
+				return(invisible())
+			}
+			
+			for (line in .catLines) {
+				cat(line)
+			}
+		},
+		
+		.showParametersOfOneGroup = function(parameters, title, 
+				orderByParameterName = TRUE, consoleOutputEnabled = TRUE) {
 			output <- ""
-			if (is.na(parameters) || length(parameters) == 0) {
-				if (!missing(title) && !is.null(title)) {
+			if (is.null(parameters) || length(parameters) == 0 || all(is.na(parameters))) {
+				if (!missing(title) && !is.null(title) && !is.na(title) && consoleOutputEnabled) {
 					output <- paste0(title, ": not available\n\n")
-					cat(output)
+					.cat(output, heading = 2, consoleOutputEnabled = consoleOutputEnabled)
 				}
 				invisible(output)
 			} else {
@@ -234,19 +503,21 @@ ParameterSet <- setRefClass("ParameterSet",
 					parameters <- sort(parameters)
 				}
 				
-				if (!missing(title) && !is.null(title)) {
+				if (!missing(title) && !is.null(title) && !is.na(title)) {
 					output <- paste0(title, ":\n")
-					cat(output)
+					.cat(output, heading = 2, consoleOutputEnabled = consoleOutputEnabled)
 				}
 				for (parameterName in parameters) {
-					output <- paste0(output, .showParameter(parameterName))
+					output <- paste0(output, .showParameter(parameterName, 
+						consoleOutputEnabled = consoleOutputEnabled))
 				}			
-				cat("\n")
+				.cat("\n", consoleOutputEnabled = consoleOutputEnabled)
 				output <- paste0(output, "\n")
 				invisible(output)				
 			}
 		},
-		.showParameter = function(parameterName, showParameterType = FALSE) {
+		
+		.showParameter = function(parameterName, showParameterType = FALSE, consoleOutputEnabled = TRUE) {
 			param <- .getParameterValueFormatted(parameterName = parameterName)
 			output <- ""
 			if (!is.null(param)) {
@@ -256,15 +527,18 @@ ParameterSet <- setRefClass("ParameterSet",
 							paramValue = param$paramValue[i, ], 
 							paramValueFormatted = param$paramValueFormatted[[i]], 
 							showParameterType = showParameterType,
-							matrixRow = i))
+							matrixRow = i, consoleOutputEnabled = consoleOutputEnabled,
+							paramNameRaw = parameterName))
 					}
 				} else {
 					output <- .showParameterFormatted(paramName = param$paramName, paramValue = param$paramValue, 
-						paramValueFormatted = param$paramValueFormatted, showParameterType = showParameterType)
+						paramValueFormatted = param$paramValueFormatted, showParameterType = showParameterType, 
+						consoleOutputEnabled = consoleOutputEnabled, paramNameRaw = parameterName)
 				}
 			}
 			invisible(output)
 		},
+		
 		.getParameterValueFormatted = function(parameterName) {
 			tryCatch({					
 				d <- regexpr("\\.design\\$", parameterName)
@@ -294,7 +568,8 @@ ParameterSet <- setRefClass("ParameterSet",
 						isMatrix <- TRUE
 						paramValueFormatted <- list(paramValueFormatted)
 						for (i in 2:nrow(matrixFormatted)) {
-							paramValueFormatted <- c(paramValueFormatted, .arrayToString(matrixFormatted[i, ]))
+							paramValueFormatted <- c(paramValueFormatted, 
+								.arrayToString(matrixFormatted[i, ]))
 						}
 					}
 				}
@@ -320,22 +595,32 @@ ParameterSet <- setRefClass("ParameterSet",
 		
 			return(NULL)
 		},
-		.showUnknownParameters = function() {
+		
+		.showUnknownParameters = function(consoleOutputEnabled = TRUE) {
 			params <- .getUndefinedParameters()
 			if (length(params) > 0) {
-				.showParametersOfOneGroup(params, "ISSUES (parameters with undefined type)")
+				.showParametersOfOneGroup(params, "ISSUES (parameters with undefined type)",
+					consoleOutputEnabled = consoleOutputEnabled)
 			}
 		},
+		
 		.showParameterFormatted = function(paramName, paramValue, paramValueFormatted = NA_character_,
-				showParameterType = FALSE, matrixRow = NA_real_) {
-			paramCaption <- .parameterNames[[paramName]]
+				showParameterType = FALSE, matrixRow = NA_real_, consoleOutputEnabled = TRUE,
+				paramNameRaw = NA_character_) {
+			if (!is.na(paramNameRaw)) {
+				paramCaption <- .parameterNames[[paramNameRaw]]
+			}
+			if (is.null(paramCaption)) {
+				paramCaption <- .parameterNames[[paramName]]
+			}
 			if (is.null(paramCaption)) {
 				paramCaption <- paste0("%", paramName, "%")
 			}
 			if (!is.na(matrixRow)) {
 				paramCaption <- paste0(paramCaption, " [", matrixRow, "]")
 			}
-			if (is.null(paramValueFormatted) || length(paramValueFormatted) == 0 || is.na(paramValueFormatted)) {
+			if (is.null(paramValueFormatted) || length(paramValueFormatted) == 0 || 
+					is.na(paramValueFormatted)) {
 				paramValueFormatted <- paramValue
 			}
 			if (is.list(paramValueFormatted)) {
@@ -344,9 +629,10 @@ ParameterSet <- setRefClass("ParameterSet",
 			prefix <- ifelse(showParameterType, .showParameterType(paramName), "")
 			variableNameFormatted <- formatVariableName(name = paramCaption, n = .getNChar(), prefix = prefix)
 			output <- paste(variableNameFormatted, paramValueFormatted, "\n")
-			cat(output)
+			.cat(output, consoleOutputEnabled = consoleOutputEnabled)
 			invisible(output)
 		},
+		
 		.getNChar = function() {
 			if (length(.parameterNames) == 0) {
 				return(40)
@@ -354,15 +640,17 @@ ParameterSet <- setRefClass("ParameterSet",
 			
 			return(min(40, max(nchar(.parameterNames))) + 4)
 		},
-		.showParameterTypeDescription = function() {
-			cat("\n")
-			cat("Legend:\n")
-			cat("  ", C_PARAM_USER_DEFINED, ": user defined\n")
-			cat("  ", C_PARAM_DERIVED, ": derived value\n")
-			cat("  ", C_PARAM_DEFAULT_VALUE, ": default value\n")
-			cat("  ", C_PARAM_GENERATED, ": generated/calculated value\n")
-			cat("  ", C_PARAM_NOT_APPLICABLE, ": not applicable for specified values\n")
+		
+		.showParameterTypeDescription = function(consoleOutputEnabled = consoleOutputEnabled) {
+			.cat("\n", consoleOutputEnabled = consoleOutputEnabled)
+			.cat("Legend:\n", heading = 2, consoleOutputEnabled = consoleOutputEnabled)
+			.cat("  ", C_PARAM_USER_DEFINED, ": user defined\n", consoleOutputEnabled = consoleOutputEnabled)
+			.cat("  ", C_PARAM_DERIVED, ": derived value\n", consoleOutputEnabled = consoleOutputEnabled)
+			.cat("  ", C_PARAM_DEFAULT_VALUE, ": default value\n", consoleOutputEnabled = consoleOutputEnabled)
+			.cat("  ", C_PARAM_GENERATED, ": generated/calculated value\n", consoleOutputEnabled = consoleOutputEnabled)
+			.cat("  ", C_PARAM_NOT_APPLICABLE, ": not applicable or hidden\n", consoleOutputEnabled = consoleOutputEnabled)
 		},
+		
 		.printAsDataFrame = function(parameterNames, niceColumnNamesEnabled = TRUE,
 				includeAllParameters = FALSE, handleParameterNamesAsToBeExcluded = FALSE,
 				lineBreakEnabled = FALSE) {
@@ -385,12 +673,14 @@ ParameterSet <- setRefClass("ParameterSet",
 			if (.isTrialDesignPlan(.self)) {
 				dimnames(result)[[1]] <- paste("  ", c(1:nrow(dataFrame)))
 			} else {
-				dimnames(result)[[1]] <- paste("  Stage", c(1:nrow(dataFrame)))
+				if (!is.null(.self[["stages"]])) {
+					dimnames(result)[[1]] <- paste("  Stage", c(1:nrow(dataFrame)))
+				}
 			}
 			
-			
 			print(result, quote=FALSE, right=FALSE)
 		},
+		
 		.getNumberOfRows = function(parameterNames) {
 			numberOfRows <- 1
 			for (parameterName in parameterNames) {
@@ -398,9 +688,14 @@ ParameterSet <- setRefClass("ParameterSet",
 				if (is.vector(parameterValues) && length(parameterValues) > numberOfRows) {
 					numberOfRows <- length(parameterValues)
 				}
+				else if (is.matrix(parameterValues) && (nrow(parameterValues) == 1 || ncol(parameterValues) == 1) && 
+						length(parameterValues) > numberOfRows) {
+					numberOfRows <- length(parameterValues)
+				}
 			}
 			return(numberOfRows)
 		},
+		
 		.getAsDataFrame = function(parameterNames, niceColumnNamesEnabled = TRUE, 
 				includeAllParameters = FALSE, handleParameterNamesAsToBeExcluded = FALSE,
 				returnParametersAsCharacter = FALSE, tableColumnNames = C_TABLE_COLUMN_NAMES) {
@@ -418,7 +713,8 @@ ParameterSet <- setRefClass("ParameterSet",
 			}
 				
 			for (parameterName in parameterNames) {
-				if (is.matrix(.self[[parameterName]])) {
+				parameterValues <- .self[[parameterName]]
+				if (is.matrix(parameterValues) && nrow(parameterValues) != 1 && ncol(parameterValues) != 1) {
 					parameterNames <- parameterNames[parameterNames != parameterName]
 				}
 			}
@@ -582,6 +878,37 @@ as.data.frame.ParameterSet <- function(x, row.names = NULL,
 			niceColumnNamesEnabled = niceColumnNamesEnabled, includeAllParameters = includeAllParameters))
 }
 
+#'
+#' @name FrameSet_as.matrix
+#' 
+#' @title
+#' Coerce Frame Set to a Matrix
+#'
+#' @description
+#' Returns the \code{FrameSet} as matrix.
+#' 
+#' @details
+#' Coerces the frame set to a matrix.
+#' 
+#' @export
+#' 
+#' @keywords internal
+#' 
+as.matrix.FieldSet <- function(x, rownames.force = NA, ...) {
+	dataFrame <- as.data.frame(x)
+	result <- as.matrix(dataFrame)
+	if ((is.na(rownames.force) || isTRUE(rownames.force)) && nrow(result) > 0) {
+		if (.isTrialDesignPlan(x)) {
+			dimnames(result)[[1]] <- paste("  ", c(1:nrow(dataFrame)))
+		} else {
+			if (!is.null(x[["stages"]]) || class(x) == "PowerAndAverageSampleNumberResult") {
+				dimnames(result)[[1]] <- paste("  Stage", c(1:nrow(dataFrame)))
+			}
+		}
+	}
+	return(result)
+}
+
 #'
 #' @name ParameterSet_summary
 #' 
@@ -599,12 +926,22 @@ as.data.frame.ParameterSet <- function(x, row.names = NULL,
 #' @keywords internal
 #' 
 summary.ParameterSet <- function(object, ...) {
-	cat("This output summarizes the", object$.toString(), "specification.\n\n")
+	object$.cat("This output summarizes the ", object$.toString(), " specification.\n\n", heading = 1)
 	object$show()
-	cat("\n")
+	object$.cat("\n")
 	object$show(showType = 2)
-	cat("\n")
-	print.ParameterSet(object, ...) 
+	object$.cat("\n")
+
+	object$.cat(object$.toString(startWithUpperCase = TRUE), " table:\n", heading = 1)
+	parametersToShow <- object$.getParametersToShow()
+	parametersToShow <- parametersToShow[parametersToShow != "stages" & parametersToShow != "stage"]
+	for (parameter in parametersToShow) {
+		if (length(object[[parameter]]) == 1) {
+			parametersToShow <- parametersToShow[parametersToShow != parameter]
+		}
+	}
+	object$.printAsDataFrame(parameterNames = parametersToShow)
+	invisible(object)
 }
 
 #'
@@ -616,6 +953,10 @@ summary.ParameterSet <- function(object, ...) {
 #' @description
 #' \code{print} prints its \code{ParameterSet} argument and returns it invisibly (via \code{invisible(x)}). 
 #' 
+#' @param x The object to print.
+#' @param markdown If \code{TRUE}, the object \code{x} will be printed using markdown syntax; 
+#'        normal representation will be used otherwise (default is \code{FALSE})
+#' 
 #' @details
 #' Prints the parameters and results of a parameter set.
 #'
@@ -623,15 +964,12 @@ summary.ParameterSet <- function(object, ...) {
 #' 
 #' @keywords internal
 #' 
-print.ParameterSet <- function(x, ...) {
-	cat(x$.toString(startWithUpperCase = TRUE), "table:\n")
-	parametersToShow <- x$.getParametersToShow()
-	parametersToShow <- parametersToShow[parametersToShow != "stages" & parametersToShow != "stage"]
-	for (parameter in parametersToShow) {
-		if (length(x[[parameter]]) == 1) {
-			parametersToShow <- parametersToShow[parametersToShow != parameter]
-		}
+print.ParameterSet <- function(x, ..., markdown = FALSE) {
+	if (markdown) {
+		x$.catMarkdownText()
+		return(invisible(x))
 	}
-	x$.printAsDataFrame(parameterNames = parametersToShow)
+	
+	x$show()
 	invisible(x)
 }
